==> ph-xml-8.6.3-test-sources.jar: com/helger/xml/serialize/read/SAXReaderDefaultSettingsTest.java <==
/**
 * Copyright (C) 2014-2017 Philip Helger (www.helger.com)
 * philip[at]helger[dot]com
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.helger.xml.serialize.read;

import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertNotNull;
import static org.junit.Assert.assertNull;
import static org.junit.Assert.assertTrue;

import org.junit.Test;

/**
 * Test class for {@link SAXReaderDefaultSettings}
 *
 * @author Philip Helger
 */
public final class SAXReaderDefaultSettingsTest
{
  @Test
  public void testDefault ()
  {
    assertFalse (SAXReaderDefaultSettings.requiresNewXMLParser ());
    assertNull (SAXReaderDefaultSettings.getEntityResolver ());
    assertNull (SAXReaderDefaultSettings.getDTDHandler ());
    assertNull (SAXReaderDefaultSettings.getContentHandler ());
    assertNotNull (SAXReaderDefaultSettings.getErrorHandler ());
    assertFalse (SAXReaderDefaultSettings.hasAnyFeature ());
    assertFalse (SAXReaderDefaultSettings.hasAnyProperties ());
    assertNotNull (SAXReaderDefaultSettings.getExceptionHandler ());
    assertFalse (SAXReaderDefaultSettings.isRequiresNewXMLParserExplicitly ());

    assertFalse (SAXReaderDefaultSettings.requiresNewXMLParser ());
    SAXReaderDefaultSettings.setRequiresNewXMLParserExplicitly (true);
    assertTrue (SAXReaderDefaultSettings.isRequiresNewXMLParserExplicitly ());
    assertTrue (SAXReaderDefaultSettings.requiresNewXMLParser ());
    SAXReaderDefaultSettings.setRequiresNewXMLParserExplicitly (false);
    assertFalse (SAXReaderDefaultSettings.isRequiresNewXMLParserExplicitly ());
    assertFalse (SAXReaderDefaultSettings.requiresNewXMLParser ());
  }
}

==> ph-xml-9.0.0-b2-test-sources.jar: com/helger/xml/serialize/read/SAXReaderDefaultSettingsTest.java <==
/**
 * Copyright (C) 2014-2017 Philip Helger (www.helger.com)
 * philip[at]helger[dot]com
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.helger.xml.serialize.read;

import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertNotNull;
import static org.junit.Assert.assertNull;
import static org.junit.Assert.assertTrue;

import org.junit.Test;

/**
 * Test class for {@link SAXReaderDefaultSettings}
 *
 * @author Philip Helger
 */
public final class SAXReaderDefaultSettingsTest
{
  @Test
  public void testDefault ()
  {
    assertFalse (SAXReaderDefaultSettings.requiresNewXMLParser ());
    assertNull (SAXReaderDefaultSettings.getEntityResolver ());
    assertNull (SAXReaderDefaultSettings.getDTDHandler ());
    assertNull (SAXReaderDefaultSettings.getContentHandler ());
    assertNotNull (SAXReaderDefaultSettings.getErrorHandler ());
    assertFalse (SAXReaderDefaultSettings.hasAnyFeature ());
    assertFalse (SAXReaderDefaultSettings.hasAnyProperties ());
    assertNotNull (SAXReaderDefaultSettings.exceptionCallbacks ());
    assertFalse (SAXReaderDefaultSettings.isRequiresNewXMLParserExplicitly ());

    assertFalse (SAXReaderDefaultSettings.requiresNewXMLParser ());
    SAXReaderDefaultSettings.setRequiresNewXMLParserExplicitly (true);
    assertTrue (SAXReaderDefaultSettings.isRequiresNewXMLParserExplicitly ());
    assertTrue (SAXReaderDefaultSettings.requiresNewXMLParser ());
    SAXReaderDefaultSettings.setRequiresNewXMLParserExplicitly (false);
    assertFalse (SAXReaderDefaultSettings.isRequiresNewXMLParserExplicitly ());
    assertFalse (SAXReaderDefaultSettings.requiresNewXMLParser ());
  }
}
